package com.ruoyi.app.service;

import java.util.List;
import com.ruoyi.app.model.PigCategory;

/**
 * 生猪分类Service接口
 * 
 * @author coede
 * @date 2025-03-19
 */
public interface IPigCategoryService 
{
    /**
     * 查询生猪分类
     * 
     * @param id 生猪分类主键
     * @return 生猪分类
     */
    public PigCategory selectPigCategoryById(Long id);

    /**
     * 查询生猪分类列表
     * 
     * @param pigCategory 生猪分类
     * @return 生猪分类集合
     */
    public List<PigCategory> selectPigCategoryList(PigCategory pigCategory);

    /**
     * 校验分类名称是否唯一
     *
     * @param  pigCategory 生猪分类
     * @return 结果
     */
    public boolean checkCategoryNameUnique(PigCategory pigCategory);

    /**
     * 新增生猪分类
     * 
     * @param pigCategory 生猪分类
     * @return 结果
     */
    public int insertPigCategory(PigCategory pigCategory);

    /**
     * 修改生猪分类
     * 
     * @param pigCategory 生猪分类
     * @return 结果
     */
    public int updatePigCategory(PigCategory pigCategory);

    /**
     * 批量删除生猪分类
     * 
     * @param ids 需要删除的生猪分类主键集合
     * @return 结果
     */
    public int deletePigCategoryByIds(Long[] ids);

    /**
     * 删除生猪分类信息
     * 
     * @param id 生猪分类主键
     * @return 结果
     */
    public int deletePigCategoryById(Long id);
}
